@@ -188,7 +188,7 @@ static struct cfg_schema_entry _interface_entries[] = {
   CFG_MAP_ACL_V46(oonf_packet_managed_config, acl, "acl", ACL_DEFAULT_ACCEPT,
     "Access control list for RFC5444 interface"),
   CFG_MAP_ACL_V46(oonf_packet_managed_config, bindto, "bindto",
-      "-127.0.0.0/8\0" "-::1\0" ACL_DEFAULT_ACCEPT,
+      "-127.0.0.0/8\0" "fe80::/10\0" "-::/0\0" ACL_FIRST_ACCEPT "\0" ACL_DEFAULT_ACCEPT,
     "Bind RFC5444 socket to an address matching this filter (both IPv4 and IPv6)"),
   CFG_MAP_NETADDR_V4(oonf_packet_managed_config, multicast_v4, "multicast_v4", RFC5444_MANET_MULTICAST_V4_TXT,
     "ipv4 multicast address of this socket", false, true),
@@ -732,8 +732,6 @@ oonf_rfc5444_reconfigure_interface(struct oonf_rfc5444_interface *interf,
       interf->name, interf->_socket_config.port, interf->_socket_config.multicast_port,
       interf->_socket_config.protocol);
 
-  OONF_DEBUG(LOG_RFC5444, "compare: '%s' == '%s'",
-      interf->name, RFC5444_UNICAST_INTERFACE);
   if (strcmp(interf->name, RFC5444_UNICAST_INTERFACE) == 0) {
     /* unicast interface */
     netaddr_invalidate(&interf->_socket_config.multicast_v4);
@@ -879,7 +877,7 @@ oonf_rfc5444_target_get_local_socket(struct oonf_rfc5444_target *target) {
 }
 
 /**
- * @param interface oonf rfc5444 interface
+ * @param rfc5444_if oonf rfc5444 interface
  * @param af_type address family type
  * @return local socket corresponding to address family
  */
@@ -1080,12 +1078,14 @@ static void
 _cb_send_multicast_packet(struct rfc5444_writer *writer __attribute__((unused)),
     struct rfc5444_writer_target *target, void *ptr, size_t len) {
   struct oonf_rfc5444_target *t;
+  struct os_interface_listener *if_listener;
   union netaddr_socket sock;
 
   t = container_of(target, struct oonf_rfc5444_target, rfc5444_target);
 
+  if_listener = oonf_rfc5444_get_core_if_listener(t->interface);
   netaddr_socket_init(&sock, &t->dst, t->interface->protocol->port,
-      t->interface->_socket._if_listener.interface->data.index);
+      if_listener->data->index);
 
   _print_packet_to_buffer(LOG_RFC5444_W, &sock, t->interface, ptr, len,
       "Outgoing RFC5444 packet to",
@@ -1111,11 +1111,13 @@ _cb_send_unicast_packet(struct rfc5444_writer *writer __attribute__((unused)),
     struct rfc5444_writer_target *target, void *ptr, size_t len) {
   struct oonf_rfc5444_target *t;
   union netaddr_socket sock;
+  struct os_interface_listener *interf;
 
   t = container_of(target, struct oonf_rfc5444_target, rfc5444_target);
 
+  interf = oonf_rfc5444_get_core_if_listener(t->interface);
   netaddr_socket_init(&sock, &t->dst, t->interface->protocol->port,
-      t->interface->_socket._if_listener.interface->data.index);
+      interf->data->index);
 
   _print_packet_to_buffer(LOG_RFC5444_W, &sock, t->interface, ptr, len,
       "Outgoing RFC5444 packet to",
@@ -1361,13 +1363,15 @@ _cb_cfg_rfc5444_changed(void) {
 static void
 _cb_cfg_interface_changed(void) {
   struct oonf_packet_managed_config config;
-
   struct oonf_rfc5444_interface *interf;
+  const char *ifname;
+  char ifbuf[IF_NAMESIZE];
   int result;
 
+  ifname = cfg_get_phy_if(ifbuf, _interface_section.section_name);
+
   interf = avl_find_element(
-      &_rfc5444_protocol->_interface_tree,
-      _interface_section.section_name, interf, _node);
+      &_rfc5444_protocol->_interface_tree, ifname, interf, _node);
 
   if (_interface_section.post == NULL) {
     /* this section has been removed */
@@ -1383,17 +1387,16 @@ _cb_cfg_interface_changed(void) {
   if (result) {
     OONF_WARN(LOG_RFC5444,
         "Could not convert "CFG_INTERFACE_SECTION" '%s' to binary (%d)",
-        _interface_section.section_name, -(result+1));
+        ifname, -(result+1));
     goto interface_changed_cleanup;
   }
 
   if (_interface_section.pre == NULL) {
-    interf = oonf_rfc5444_add_interface(_rfc5444_protocol,
-        NULL, _interface_section.post->name);
+    interf = oonf_rfc5444_add_interface(_rfc5444_protocol, NULL, ifname);
     if (interf == NULL) {
       OONF_WARN(LOG_RFC5444,
           "Could not generate interface '%s' for protocol '%s'",
-          _interface_section.section_name, _rfc5444_protocol->name);
+          ifname, _rfc5444_protocol->name);
       goto interface_changed_cleanup;
     }
   }
